@@ -508,8 +508,8 @@ class Compare:
                 orig_col_name = col[:-6]
 
                 col_comparison = columns_equal(
-                    self.df1[orig_col_name],
-                    self.df2[orig_col_name],
+                    self.intersect_rows[orig_col_name + "_df1"],
+                    self.intersect_rows[orig_col_name + "_df2"],
                     self.rel_tol,
                     self.abs_tol,
                     self.ignore_spaces,
